
# -------------------------------------------------------------------------
# FRAMING PAPER - Measures 
# -------------------------------------------------------------------------
#
# Author: EVANTHIA DIMARA
# 
# -------------------------------------------------------------------------
# Measures
# -------------------------------------------------------------------------
# User Performance: Accuracy, Attention, Recall
# User Experience:  Confidence, Easiness, Ejoyability, Usefulness
# User Behavior:    InstructionsTime, VisualizationTime, Backs
# -------------------------------------------------------------------------

library(boot)
library(simpleboot)

source("load-observations.R")
source("functions.R")

digits  <- 2 # number of digits to show after the decimal point.

accuracy <- function(condition1, condition2, results) 
{
  accuracyCI        <- diffMeanCI(condition1, condition2)  
  accuracyCIform    <- format_ci( accuracyCI, digits, width = NA, TRUE)
  labelText         <- sprintf("%s | %s - %s", accuracyCIform, deparse(substitute(condition1)), deparse(substitute(condition2))) 
  cat("\n Difference in means " ,  labelText)
  results           <- rbind(results, data.frame(label = labelText , point = accuracyCI[1], ci.lower = accuracyCI[2], ci.upper = accuracyCI[3], type='Other')) 
}


attention <- function(condition1, condition2, results) 
{
  attentionCI       <- diffpropCI(sum(condition1), length(condition1), sum(condition2),  length(condition2)) 
  attentionCIform   <- format_ci( attentionCI, digits, width = NA, TRUE)
  labelText         <- sprintf("%s | %s - %s", attentionCIform, deparse(substitute(condition1)), deparse(substitute(condition2))) 
  cat("\nDifference in proportions ", labelText)
  results           <- rbind(results, data.frame(label =labelText , point = attentionCI[1], ci.lower = attentionCI[2], ci.upper = attentionCI[3], type='Other'))  
}

recall <- function(condition1, condition2, results) 
{
  recallCI         <- diffpropCI(sum(condition1), length(condition1), sum(condition2),  length(condition2)) 
  recallCIform     <- format_ci( recallCI, digits, width = NA, TRUE)
  labelText        <- sprintf("%s | %s - %s", recallCIform, deparse(substitute(condition1)), deparse(substitute(condition2))) 
  cat("\nDifference in proportions ", labelText)
  results          <- rbind(results, data.frame(label =labelText , point = recallCI[1], ci.lower = recallCI[2], ci.upper = recallCI[3], type='Other'))  
}

confidence <- function(condition1, condition2, results) 
{  
  confidenceCI        <- diffMeanCI(condition1, condition2)  
  confidenceCIform    <- format_ci( confidenceCI, digits, width = NA, TRUE)
  labelText           <- sprintf("%s | %s - %s", confidenceCIform, deparse(substitute(condition1)), deparse(substitute(condition2))) 
  cat("\n Difference in means " ,  labelText)
  results             <- rbind(results, data.frame(label = labelText , point = confidenceCI[1], ci.lower = confidenceCI[2], ci.upper = confidenceCI[3], type='Other')) 
}

easiness <- function(condition1, condition2, results) 
{
  easinessCI         <- diffMeanCI(condition1, condition2)  
  easinessCIform     <- format_ci( easinessCI, digits, width = NA, TRUE)
  labelText          <- sprintf("%s | %s - %s", easinessCIform, deparse(substitute(condition1)), deparse(substitute(condition2))) 
  cat("\n Difference in means " ,  labelText)
  results            <- rbind(results, data.frame(label = labelText , point = easinessCI[1], ci.lower = easinessCI[2], ci.upper = easinessCI[3], type='Other')) 
}

enjoyability <- function(condition1, condition2, results) 
{  
  enjoyabilityCI        <- diffMeanCI(condition1, condition2)  
  enjoyabilityCIform    <- format_ci( enjoyabilityCI, digits, width = NA, TRUE)
  labelText           <- sprintf("%s | %s - %s", enjoyabilityCIform, deparse(substitute(condition1)), deparse(substitute(condition2))) 
  cat("\n Difference in means " ,  labelText)
  results             <- rbind(results, data.frame(label = labelText , point = enjoyabilityCI[1], ci.lower = enjoyabilityCI[2], ci.upper = enjoyabilityCI[3], type='Other')) 
}

usefulness <- function(condition1, condition2, results) 
{  
  usefulnessCI        <- diffMeanCI(condition1, condition2)  
  usefulnessCIform    <- format_ci(usefulnessCI, digits, width = NA, TRUE)
  labelText           <- sprintf("%s | %s - %s", usefulnessCIform, deparse(substitute(condition1)), deparse(substitute(condition2))) 
  cat("\n Difference in means " ,  labelText)
  results             <- rbind(results, data.frame(label = labelText , point = usefulnessCI[1], ci.lower =usefulnessCI[2], ci.upper = usefulnessCI[3], type='Other')) 
}

accuracy1Condition <- function(condition, results) 
{
  accuracyCI        <- meanCI(condition)  
  accuracyCIform    <- format_ci( accuracyCI, digits, width = NA, TRUE)
  labelText         <- sprintf("%s | %s", accuracyCIform, deparse(substitute(condition))) 
  cat("\n Mean CI " ,  labelText)
  results           <- rbind(results, data.frame(label = labelText , point = accuracyCI[1], ci.lower = accuracyCI[2], ci.upper = accuracyCI[3], type='Other')) 
}

attention1Condition <- function(condition, results) 
{
  attentionCI        <- meanCI(condition)  
  attentionCIform    <- format_ci( attentionCI, digits, width = NA, TRUE)
  labelText          <- sprintf("%s | %s", attentionCIform, deparse(substitute(condition))) 
  cat("\n Mean CI " ,  labelText)
  results            <- rbind(results, data.frame(label = labelText , point = attentionCI[1], ci.lower = attentionCI[2], ci.upper = attentionCI[3], type='Other')) 
}

recall1Condition <- function(condition, results) 
{
  recallCI          <- meanCI(condition)  
  recallCIform      <- format_ci( recallCI, digits, width = NA, TRUE)
  labelText         <- sprintf("%s | %s", recallCIform, deparse(substitute(condition))) 
  cat("\n Mean CI " ,  labelText)
  results           <- rbind(results, data.frame(label = labelText , point = recallCI[1], ci.lower = recallCI[2], ci.upper = recallCI[3], type='Other')) 
}

confidence1Condition <- function(condition, results) 
{
  confidenceCI          <- meanCI(condition)  
  confidenceCIform      <- format_ci( confidenceCI, digits, width = NA, TRUE)
  labelText             <- sprintf("%s | %s", confidenceCIform, deparse(substitute(condition))) 
  cat("\n Mean CI " ,  labelText)
  results               <- rbind(results, data.frame(label = labelText , point = confidenceCI[1], ci.lower = confidenceCI[2], ci.upper = confidenceCI[3], type='Other')) 
}

easiness1Condition <- function(condition, results) 
{
  easinessCI          <- meanCI(condition)  
  easinessCIform      <- format_ci(easinessCI, digits, width = NA, TRUE)
  labelText           <- sprintf("%s | %s", easinessCIform, deparse(substitute(condition))) 
  cat("\n Mean CI " ,  labelText)
  results             <- rbind(results, data.frame(label = labelText , point =easinessCI[1], ci.lower = easinessCI[2], ci.upper = easinessCI[3], type='Other')) 
}

enjoyability1Condition <- function(condition, results) 
{
  enjoyabilityCI      <- meanCI(condition)  
  enjoyabilityCIform  <- format_ci(enjoyabilityCI, digits, width = NA, TRUE)
  labelText           <- sprintf("%s | %s", enjoyabilityCIform, deparse(substitute(condition))) 
  cat("\n Mean CI " ,  labelText)
  results             <- rbind(results, data.frame(label = labelText , point = enjoyabilityCI[1], ci.lower = enjoyabilityCI[2], ci.upper = enjoyabilityCI[3], type='Other')) 
}

usefulness1Condition <- function(condition, results) 
{
  usefulnessCI        <- meanCI(condition)  
  usefulnessCIform    <- format_ci(usefulnessCI, digits, width = NA, TRUE)
  labelText           <- sprintf("%s | %s", usefulnessCIform, deparse(substitute(condition))) 
  cat("\n Mean CI " ,  labelText)
  results             <- rbind(results, data.frame(label = labelText , point = usefulnessCI[1], ci.lower = usefulnessCI[2], ci.upper = usefulnessCI[3], type='Other')) 
}
