# -------------------------------------------------------------------------
# FRAMING PAPER - Plots 
# -------------------------------------------------------------------------
# Author: EVANTHIA DIMARA
# modifying the code of Pierre Dragicevic in Attraction Effect paper
# -------------------------------------------------------------------------

plotAllCI <- function(results) {
  plotRange <- c(-.8, .8)
  palette <- c("#888888", "#EE4444", "#000000", "#4466FF")
  results$type <- as.factor(results$type)
  rows.to.plot <- 1:(nrow(results)-1) # plot all but the within-pair consistency score
  results.to.plot <- results[rows.to.plot,]
  # Simplify the ggplot visual theme
  theme_set(theme_bw() + theme(
    axis.title = element_blank(),
    axis.text.y = element_blank(),
    axis.ticks = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.x = element_line(color = "#000000", size = 0.05),
    panel.grid.minor.x = element_line(color = "#000000", size = 0.05),
    panel.border = element_blank(),
    legend.key.size = unit(5,"mm"), 
    plot.margin=unit(c(0.2, 0.2, 0.2, 0.2),"cm"),
    text = element_text(size=17)))
  
  # Plot all confidence intervals
  p <- ggplot(data = results.to.plot, aes(x = rev(rows.to.plot), y = point, label=label, col=type)) +
    scale_color_manual(values=palette) +
    geom_pointrange(aes(ymin=ci.lower, ymax=ci.upper), size=0.9) +
    geom_point(size=0.9*5, colour="#ffffff", pch=21) +
    geom_text(y=plotRange[1], hjust=0, size=5.0) +
    geom_abline(intercept = 0, slope = 0, lty = 3, size=0.8) +
    scale_y_continuous(limits = plotRange, labels = scales::percent, breaks=seq(-0.2, 0.6, 0.2)) +
    coord_flip()

}

plotAllCI2 <- function(results) {
  plotRange <- c(-.9, .9)
  palette <- c("#888888", "#EE4444", "#000000", "#4466FF")
  results$type <- as.factor(results$type)
  rows.to.plot <- 1:(nrow(results)) # plot all but the within-pair consistency score
  results.to.plot <- results[rows.to.plot,]
  # Simplify the ggplot visual theme
  theme_set(theme_bw() + theme(
    axis.title = element_blank(),
    axis.text.y = element_blank(),
    axis.ticks = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.x = element_line(color = "#000000", size = 0.05),
    panel.grid.minor.x = element_line(color = "#000000", size = 0.05),
    panel.border = element_blank(),
    legend.key.size = unit(5,"mm"), 
    plot.margin=unit(c(0.1, 0.1, 0.1, 0.1),"cm"), #up, 
    text = element_text(size=17)))
  
  # Plot all confidence intervals
  p <- ggplot(data = results.to.plot, aes(x = rev(rows.to.plot), y = point, label=label)) +
    geom_pointrange(aes(ymin=ci.lower, ymax=ci.upper), size=1) +
    geom_point(size=0.9*5, colour="#ffffff", pch=21) +
    geom_text(color="#888888",y=plotRange[1], hjust=0, size=4.0) +
    geom_abline(intercept = 0, slope = 0, lty = 3, size=0.8) +
    scale_y_continuous(limits = plotRange, labels = scales::percent, breaks=seq(-0.2, 0.6, 0.2)) +
    coord_flip()
  
}

plotAllCI3 <- function(results) {
  plotRange <- c(-1, 1)
  palette <- c("#888888", "#EE4444", "#000000", "#4466FF")
  results$type <- as.factor(results$type)
  rows.to.plot <- 1:(nrow(results)) # plot all but the within-pair consistency score
  results.to.plot <- results[rows.to.plot,]
  # Simplify the ggplot visual theme
  theme_set(theme_bw() + theme(
    axis.title = element_blank(),
    axis.text.y = element_blank(),
    axis.ticks = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.x = element_line(color = "#000000", size = 0.05),
    panel.grid.minor.x = element_line(color = "#000000", size = 0.05),
    panel.border = element_blank(),
    legend.key.size = unit(5,"mm"), 
    plot.margin=unit(c(0.1, 0.1, 0.1, 0.1),"cm"), #up, 
    text = element_text(size=17)))
  
  # Plot all confidence intervals
  p <- ggplot(data = results.to.plot, aes(x = rev(rows.to.plot), y = point, label=label)) +
    geom_pointrange(aes(ymin=ci.lower, ymax=ci.upper), size=1) +
    geom_point(size=0.9*5, colour="#ffffff", pch=21) +
    geom_text(color="#888888",y=plotRange[1], hjust=0, size=4.0) +
    geom_abline(intercept = 0, slope = 0, lty = 3, size=0.8) +
    scale_y_continuous(limits = plotRange, labels = scales::percent, breaks=seq(-0.2, 0.6, 0.2)) +
    coord_flip()
  
}


plotAllCI_extremum <- function(results) {
  plotRange <- c(-1, 1)
  palette <- c("#888888", "#EE4444", "#000000", "#4466FF")
  results$type <- as.factor(results$type)
  rows.to.plot <- 1:(nrow(results)) # plot all but the within-pair consistency score
  results.to.plot <- results[rows.to.plot,]
  # Simplify the ggplot visual theme
  theme_set(theme_bw() + theme(
    axis.title = element_blank(),
    axis.text.y = element_blank(),
    axis.ticks = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.x = element_line(color = "#000000", size = 0.05),
    panel.grid.minor.x = element_line(color = "#000000", size = 0.05),
    panel.border = element_blank(),
    legend.key.size = unit(5,"mm"), 
    plot.margin=unit(c(0.1, 0.1, 0.1, 0.1),"cm"), #up, 
    text = element_text(size=17)))
  
  # Plot all confidence intervals
  p <- ggplot(data = results.to.plot, aes(x = rev(rows.to.plot), y = point, label=label)) +
    geom_pointrange(aes(ymin=ci.lower, ymax=ci.upper), size=1) +
    geom_point(size=0.9*5, colour="#ffffff", pch=21) +
    geom_text(color="#888888",y=plotRange[1], hjust=0, size=5.0) +
    geom_abline(intercept = 0, slope = 0, lty = 3, size=0.8) +
    scale_y_continuous(limits = plotRange, labels = scales::percent, breaks=seq(-0.2, 0.6, 0.2)) +
    coord_flip()
  
}

plotAllCI_allTaks <- function(results) {
  plotRange <- c(-1, 1)
  palette <- c("#888888", "#EE4444", "#000000", "#4466FF")
  results$type <- as.factor(results$type)
  rows.to.plot <- 1:(nrow(results)) # plot all but the within-pair consistency score
  results.to.plot <- results[rows.to.plot,]
  # Simplify the ggplot visual theme
  theme_set(theme_bw() + theme(
    axis.title = element_blank(),
    axis.text.y = element_blank(),
    axis.ticks = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.x = element_line(color = "#000000", size = 0.05),
    panel.grid.minor.x = element_line(color = "#000000", size = 0.05),
    panel.border = element_blank(),
    legend.key.size = unit(5,"mm"), 
    plot.margin=unit(c(0.1, 0.1, 0.1, 0.1),"cm"), #up, 
    text = element_text(size=17)))
  
  # Plot all confidence intervals
  p <- ggplot(data = results.to.plot, aes(x = rev(rows.to.plot), y = point, label=label)) +
    geom_pointrange(aes(ymin=ci.lower, ymax=ci.upper), size=1) +
    geom_point(size=0.9*5, colour="#ffffff", pch=21) +
    geom_text(color="#888888",y=plotRange[1], hjust=0, size=5.0) +
    geom_abline(intercept = 0, slope = 0, lty = 3, size=0.8) +
    scale_y_continuous(limits = plotRange, labels = scales::percent, breaks=seq(-0.2, 0.6, 0.2)) +
    coord_flip()
  
}

